api.permissions.v1.function package — Argus-Toolbelt 1.0 documentation

# api.permissions.v1.function package

## Submodules

## api.permissions.v1.function.function module

Autogenerated API

`api.permissions.v1.function.function.` `get_function_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request information about a function by ID (DEV) Request information about a function by ID. If user does not have access to requested function, a 403 access denied will be returned.

  Return type: | `dict`

`api.permissions.v1.function.function.` `get_function_by_name`(name: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request information about a function by name (DEV) Request information about a function by name. If user does not have access to requested function, a 403 access denied will be returned.

  Return type: | `dict`

## Module contents